Enum JsonError
#[non_exhaustive]pub enum JsonError {
NotOfType {
target: String,
of_type: JsonType,
},
NotMultiplesOfType {
target: String,
of_type: JsonType,
},
JsonFieldMissingFromObject(String),
Serde(Error),
}Expand description
All errors related to JSON validation/parsing.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
NotOfType
target is not of the correct type of_type (JsonType).
Fields
NotMultiplesOfType
Like JsonError::NotOfType, only called when the target is a multiple;
array, set, etc.
Fields
JsonFieldMissingFromObject(String)
The given required field is missing from a JSON object.
Serde(Error)
A more generic JSON error from serde_json.